import { createTRPCProxyClient, httpBatchLink } from '@trpc/client';
/**
 * Create a tRPC client.
 * @see https://trpc.io/docs/vanilla
 */
export function createTRPCClient({ links, url = '/trpc', transformer, init, headers } = {
    url: '/trpc'
}) {
    if (links)
        return createTRPCProxyClient({ transformer, links });
    if (typeof window === 'undefined' && !init) {
        throw new Error('Calling createTRPCClient() on the server requires passing a valid LoadEvent argument');
    }
    return createTRPCProxyClient({
        transformer,
        links: [
            httpBatchLink({
                url: typeof window === 'undefined' ? `${init.url.origin}${url}` : `${location.origin}${url}`,
                fetch: typeof window === 'undefined' ? init.fetch : init?.fetch ?? window.fetch,
                headers
            })
        ]
    });
}
